import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  json,
  scaleLinear,
  max,
  min,
  scaleTime,
  timeParse,
  timeFormat,
  line
} from 'd3';
const width = 960;
const height = 500;
const margin = {
  left: 100,
  top: 20,
  right: 20,
  bottom: 50,
};
const App = () => {
  const [data, setData] = useState(null);
  const parseTime = timeParse('%d-%m-%Y');
	
  const formatTime = timeFormat('%Y');
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  useEffect(() => {
    json('timeperiodv2.json').then((data) => {
      let cleanData = [];
      data.response.docs.map((d) => {
        if(typeof d.data_value != 'undefined'){
         	d.start_date = parseTime(d.start_date);
          d.end_date = parseTime(d.end_date);
          d["middle_date"] = new Date((d.start_date.getTime() + d.end_date.getTime())/2);
        	cleanData.push(d);
        }
      });
      setData(cleanData);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  let listofDate = [];
  data.map((d) => {
    listofDate.push(d.start_date);
    listofDate.push(d.end_date);
  });
	
  const xScale = scaleTime()
    .domain([min(listofDate), max(listofDate)])
    .range([0, innerWidth]);

  const yScale = scaleLinear()
    .domain([0, max(data, (d) => d.data_value)])
    .range([innerHeight, 0]);
  
  const xValue = d => d.middle_date;
	const yValue = d => d.data_value;

   const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)));
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {xScale.ticks().map((tickValue) => (
          <g
            transform={`translate(${xScale(tickValue)}, 0)`}
            key={tickValue}
          >
            <line y2={innerHeight} stroke="black"></line>
            <text
              dy=".7em"
              style={{ textAnchor: 'middle' }}
              y={innerHeight + 3}
            >
              {formatTime(tickValue)}
            </text>
          </g>
        ))}

        {yScale.ticks().map((tickValue) => (
          <g key={tickValue}>
            <line
              x1={0}
              y1={yScale(tickValue)}
              x2={innerWidth}
              y2={yScale(tickValue)}
              stroke="black"
            ></line>
            <text
              x={0}
              y={yScale(tickValue)}
              style={{ textAnchor: 'end' }}
              x={-3}
              dy=".32em"
            >
              {tickValue}
            </text>
          </g>
        ))}

        {data.map((d) => (
          <g key={d.timeperiod}>
          <rect
            fill="rgba(200,255,220,.9)"
            stroke="black"
            
            y={yScale(d.data_value)}
            x={xScale(d.start_date)}
            height={yScale(0) - yScale(d.data_value)}
            width={
              xScale(d.end_date) - xScale(d.start_date)
            }
          />
            <text x={xScale(d.middle_date)} 
                 	y={yScale(d.data_value)}
              		style={{ textAnchor: 'middle',fontSize:'12' }}
              		dy="-.2em"
              >{d.timeperiod}</text>
          </g>
        ))}
        <path d={lineGenerator(data)}></path>
      </g>
    </svg>
  );
};

ReactDOM.render(<App />, document.getElementById('root'));
